"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useHoverHighlighter = void 0;
const react_1 = require("react");
const use_debounce_1 = require("use-debounce");
const react_modules_dom_to_react_1 = require("@teambit/react.modules.dom-to-react");
const react_ui_hover_selector_1 = require("@teambit/react.ui.hover-selector");
const react_ui_highlighter_component_metadata_bit_component_meta_1 = require("@teambit/react.ui.highlighter.component-metadata.bit-component-meta");
const ignore_highlighter_1 = require("../ignore-highlighter");
const rule_matcher_1 = require("../rule-matcher");
/** fires onChange when targeting a new component */
function useHoverHighlighter(onChange, props = {}, { debounceDuration, scopeClass, disabled, rule, componentRule }) {
    const { handleElement } = useHoverHandler({ onChange, scopeClass, debounceDuration, disabled, rule, componentRule });
    const handlers = (0, react_ui_hover_selector_1.useHoverSelection)(disabled ? undefined : handleElement, props);
    return handlers;
}
exports.useHoverHighlighter = useHoverHighlighter;
function useHoverHandler({ onChange, scopeClass = '', debounceDuration, disabled, rule, componentRule, }) {
    // debounced method is ref'ed, so no need for useCallback
    const _handleElement = (element) => {
        // clear highlighter at the edges:
        if (!element || element.hasAttribute('data-nullify-component-highlight')) {
            onChange(undefined);
            return;
        }
        // skip DOM trees having 'data-ignore-component-highlight'
        if (element.closest(`.${scopeClass} ${ignore_highlighter_1.excludeHighlighterSelector}`))
            return;
        const result = bubbleToBitComponent(element, rule, componentRule);
        if (!result)
            return;
        onChange({
            element: result.element,
            components: result.components,
        });
    };
    const handleElement = (0, use_debounce_1.useDebouncedCallback)(_handleElement, debounceDuration);
    // clear when disabling
    (0, react_1.useEffect)(() => {
        if (disabled)
            handleElement.cancel();
    }, [disabled, handleElement]);
    return { handleElement };
}
/** go up the dom tree until reaching a react bit component */
function bubbleToBitComponent(element, elementRule, componentRule) {
    for (let current = element; current; current = current.parentElement) {
        current = (0, react_modules_dom_to_react_1.toRootElement)(current);
        if (!current)
            return undefined;
        if ((0, rule_matcher_1.ruleMatcher)(current, elementRule)) {
            const components = (0, react_modules_dom_to_react_1.domToReacts)(current);
            const relevantComponents = components.filter((x) => (0, react_ui_highlighter_component_metadata_bit_component_meta_1.hasComponentMeta)(x) && (0, rule_matcher_1.componentRuleMatcher)({ meta: x[react_ui_highlighter_component_metadata_bit_component_meta_1.componentMetaField] }, componentRule));
            if (relevantComponents.length < 1)
                return undefined;
            return {
                element: current,
                components: relevantComponents,
            };
        }
    }
    return undefined;
}
//# sourceMappingURL=use-hover-highlighter.js.map