import React, { CSSProperties } from 'react';
import { Placement, HighlightClasses, HighlighterSize } from '../element-highlighter';
import type { MatchRule, ComponentMatchRule } from '../rule-matcher';
export interface HybridHighlighterProps extends React.HTMLAttributes<HTMLDivElement> {
    /** stop all highlighting and drop listeners */
    disabled?: boolean;
    /** default pop location for the label */
    placement?: Placement;
    /** customize styles */
    classes?: HighlightClasses;
    /** customize highlighter */
    highlightStyle?: CSSProperties;
    /** debounces element hover selection.
     * A higher value will reduce element lookups as well as "keep" the highlight on the current element for longer.
     * Initial selection (when no element is currently selected) will always happen immediately to improve the user experience.
     * @default 80ms
     */
    debounceSelection?: number;
    /** continually update frame position to match moving elements */
    watchMotion?: boolean;
    /** filter highlighter targets by this query selector. (May be a more complex object in the future) */
    rule?: MatchRule;
    /** filter components to match this rule. Can be id, array of ids, or a function */
    componentRule?: ComponentMatchRule;
    /** set the behavior of the highlighter.
     * `disabled` - stops highlighting.
     * `allChildren` - highlights all components rendered under children
     * `hover` - highlighters the component immediately under the mouse cursor
     * */
    mode?: 'allChildren' | 'hover';
    bgColor?: string;
    bgColorHover?: string;
    bgColorActive?: string;
    size?: HighlighterSize;
}
/** automatically highlight components on hover */
export declare function HybridHighlighter({ disabled, mode, debounceSelection, watchMotion, placement, rule, componentRule, classes, highlightStyle, className, style, bgColor, bgColorHover, bgColorActive, size, children, ...rest }: HybridHighlighterProps): JSX.Element;
